@@ -29,6 +29,18 @@ def _exception_handler(func):
             return None
     return _wrapper
 
+
+def show_help():
+    mess = [u'Give easykubeflow a \U0001F31F on github', 'Link to Examples https://github.com/vule24/easykubeflow/tree/master/examples']
+    _max = max(map(len, mess))
+    _max = 40 if _max < 40 else _max + 20
+    print('╔' + '═'*_max + '╗')
+    for i,m in enumerate(mess):
+        _left = (_max - len(m))//2 + 1
+        print(' '*_left + m)
+    print('╚' + '═'*_max + '╝')
+    
+
 class Utils:
     
     def __init__(self, client):
@@ -56,7 +68,15 @@ class Utils:
         self.client.delete_run_by_name = self.delete_run_by_name
         self.client.delete_runs_by_experiment = self.delete_runs_by_experiment
         self.client.upload_pipeline_version = self.upload_pipeline_version
-
+        
+        mess = 'easykubeflow.show_help() to get examples source'
+        _max = 40 if len(mess) < 40 else len(mess) + 20
+        _left = (_max - len(mess))//2 + 1
+        print('╔' + '═'*_max + '╗')
+        print('║' + ' '*_left + mess + ' '*(_max-len(mess)-_left) + '║')
+        print('╚' + '═'*_max + '╝')
+        
+        
     @_exception_handler
     def get_pipeline_by_name(self, name):
         """Get pipeline using its name.
